# Contributing to SEB Server
We want to make contributing to this project as easy and transparent as possible, whether it's:

- Give us a star
- Reporting a bug
- Submitting a fix
- Proposing new features
- Becoming a SEB Alliance member

## We Develop with Github
We use github to host code, to track issues and feature requests, as well as accept pull requests.

## We Use Git-Flow for Code Contributions
Pull requests are the best way to propose changes to the codebase (we use [Github Flow](https://www.atlassian.com/git/tutorials/comparing-workflows/gitflow-workflow)). We actively welcome your pull requests:

1. Fork the repo and create your branch from `development`. The development branch always has the newest changes.
2. If you've added code that should be tested, add tests.
3. If you introduce new API also add clear documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. Issue that pull request!

## Any contributions you make will be under the Mozilla Public License Version 2.0
In short, when you submit code changes, your submissions are understood to be under the same [Mozilla Public License](https://github.com/SafeExamBrowser/seb-server?tab=MPL-2.0-1-ov-file) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report bugs using Github's Issue
We use [Github issues](https://github.com/SafeExamBrowser/seb-server/issues) to track public bugs. Report a bug by [opening a new issue]();

## Write bug reports with detail, background, and sample code
**Before enter a new bug-report, ensure the bug was not already reported**

Please fill and provide all the information suggested by the bug-report template
Great Bug Reports tend to have:

- A quick summary and/or background
- Steps to reproduce
    - Be specific!
    - Give sample code if you can. Can also be Pseudocode.
- What you expected would happen
- What actually happens
- Notes (possibly including why you think this might be happening, or stuff you tried that didn't work)

## Use a Consistent Coding Style
Have a close look to the existing code stile that is used within SEB Server and adapt to it as close as possible.
We reserve the right to adapt contributed code to the code style matching SEB Server code style before or after a pull request.

## Becoming a SEB Alliance member
The [SEB Alliance](https://www.safeexambrowser.org/alliance/members.html) is the body which sustains ongoing funding of the Safe Exam Browser open source project to continue its maintenance, development and support activities. ETH Zurich provides the infrastructure for the management and the software engineering of the SEB project and appoints an alliance manager who will provide administrative support to the SEB Alliance, and ensure the day-to-day running of the SEB Alliance. ETH Zurich leads the Alliance and offers different contribution levels to parties interested in the evolution of the SEB open source project.

More information about [joining](https://www.safeexambrowser.org/alliance/join.html) the Alliance is available in our [benefits](https://www.safeexambrowser.org/alliance/benefits.html) and [documents](https://www.safeexambrowser.org/alliance/documents.html) section.

## License
By contributing, you agree that your contributions will be licensed under its [Mozilla Public License](https://github.com/SafeExamBrowser/seb-server?tab=MPL-2.0-1-ov-file).
